@@ -1,6 +1,6 @@
 import logging
 
-import sh
+from fabric.api import local
 
 from changes import config, shell
 
@@ -9,16 +9,15 @@ log = logging.getLogger(__name__)
 
 def run_tests():
     if config.arguments['--tox']:
-        sh.tox()
+        result = local('tox')
     else:
-        sh.nosetests()
-
-    return True
+        result = local('nosetests')
+    return result.succeeded
 
 
 def run_test_command():
     if config.arguments['--test-command']:
-        test_command = config.arguments['--test-command']
-        result = shell.execute(sh, tuple(test_command.split(' ')))
+        result = local(config.arguments['--test-command'])
         log.info('Test command "%s", returned %s', test_command, result)
+        return result.succeeded
     return True
